@@ -127,21 +127,35 @@ def query_labels(query):
 
 def query_entities(query):
     """
-    Return all entities for given SQLAlchemy query object.
+    Return a generator that iterates through all entities for given SQLAlchemy
+    query object.
 
-    Example::
+    Examples::
 
 
-        query = session.query(
-            Category
-        )
+        query = session.query(Category)
+
+        query_entities(query)  # <Category>
+
+
+        query = session.query(Category.id)
+
+        query_entities(query)  # <Category>
+
+
+    This function also supports queries with joins:
+
+
+        query = session.query(Category).join(Article)
+
+        query_entities(query)  # (<Category>, <Article>)
 
-        query_entities(query)  # ('Category', )
 
     :param query: SQLAlchemy Query object
     """
     for entity in query._entities:
-        yield entity.entity_zero.class_
+        if entity.entity_zero:
+            yield entity.entity_zero.class_
 
     for entity in query._join_entities:
         if isinstance(entity, Mapper):
